Package: desc
Title: Manipulate DESCRIPTION Files
Version: 1.0.0
Author: Gábor Csárdi
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Description: Tools to read, write, create, and manipulate DESCRIPTION
    files. It is intented for packages that create or manipulate other
    packages.
License: MIT + file LICENSE
Imports:
    httrmock,
    lintr
Remotes:
    jimhester/lintr
Encoding: UTF-8
Remotes:
    gaborcsardi/httrmock
