Package: hunspell
Type: Package
Title: High-Performance Stemmer, Tokenizer, and Spell Checker
Version: 2.9
Depends: R (>= 3.0.2)
Encoding: UTF-8
Authors@R: c(
    person("Jeroen", "Ooms", ,"jeroen@berkeley.edu", role = c("aut", "cre")),
    person("Authors of libhunspell", role = "cph", comment = "see AUTHORS file"))
Description: Low level spell checker and morphological analyzer based on the
    famous 'hunspell' library <https://hunspell.github.io>. The package can analyze
    or check individual words as well as parse text, latex, html or xml documents.
    For a more user-friendly interface use the 'spelling' package which builds on
    this package to automate checking of files, documentation and vignettes in all
    common formats.
License: GPL-2 | LGPL-2.1 | MPL-1.1
URL:
    https://github.com/ropensci/hunspell#readme (devel)
    https://hunspell.github.io (upstream)
BugReports: https://github.com/ropensci/hunspell/issues
Imports: Rcpp, digest
LinkingTo: Rcpp (>= 0.12.12)
Suggests: spelling,
    testthat,
    pdftools,
    janeaustenr,
    wordcloud2,
    knitr,
    rmarkdown
VignetteBuilder: knitr
RoxygenNote: 6.0.1.9000
