Package: igraph
Version: 1.2.6
Title: Network Analysis and Visualization
Author: See AUTHORS file.
Maintainer: Gábor Csárdi <csardi.gabor@gmail.com>
Description: Routines for simple graphs and network analysis. It can
  handle large graphs very well and provides functions for generating random
  and regular graphs, graph visualization, centrality methods and much more.
Depends: methods
Imports: graphics, grDevices, magrittr, Matrix, pkgconfig (>= 2.0.0),
        stats, utils
Suggests: ape, digest, graph, igraphdata, rgl, scales, stats4, tcltk,
        testthat, withr
License: GPL (>= 2)
URL: https://igraph.org
SystemRequirements: gmp (optional), libxml2 (optional), glpk (optional)
BugReports: https://github.com/igraph/igraph/issues
Encoding: UTF-8
RoxygenNote: 7.1.1
Collate: 'adjacency.R' 'auto.R' 'assortativity.R' 'attributes.R'
        'basic.R' 'bipartite.R' 'centrality.R' 'centralization.R'
        'cliques.R' 'cocitation.R' 'cohesive.blocks.R' 'community.R'
        'components.R' 'console.R' 'conversion.R' 'data_frame.R'
        'decomposition.R' 'degseq.R' 'demo.R' 'embedding.R' 'epi.R'
        'fit.R' 'flow.R' 'foreign.R' 'games.R' 'glet.R' 'hrg.R'
        'igraph-package.R' 'incidence.R' 'indexing.R' 'interface.R'
        'iterators.R' 'layout.R' 'layout_drl.R' 'lazyeval.R' 'make.R'
        'minimum.spanning.tree.R' 'motifs.R' 'nexus.R' 'operators.R'
        'other.R' 'package.R' 'palette.R' 'par.R' 'paths.R' 'plot.R'
        'plot.common.R' 'plot.shapes.R' 'pp.R' 'print.R' 'printr.R'
        'random_walk.R' 'rewire.R' 'scan.R' 'scg.R' 'sgm.R'
        'similarity.R' 'simple.R' 'sir.R' 'socnet.R' 'sparsedf.R'
        'structural.properties.R' 'structure.info.R' 'test.R'
        'tkplot.R' 'topology.R' 'triangles.R' 'utils.R' 'uuid.R'
        'versions.R' 'weakref.R' 'zzz-deprecate.R'
NeedsCompilation: yes
Packaged: 2020-10-06 10:36:22 UTC; gaborcsardi
Repository: CRAN
Date/Publication: 2020-10-06 12:40:05 UTC
