% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_del_remotes}
\alias{desc_del_remotes}
\title{Delete locations from the Remotes field in DESCRIPTION}
\usage{
desc_del_remotes(pattern, file = ".", normalize = FALSE)
}
\arguments{
\item{pattern}{Perl-compatible regular expression, all locations
matching this expression will be deleted.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
All locations matching the specified pattern are deleted.
}
