% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_get_deps}
\alias{desc_get_deps}
\title{List all package dependencies from a DESCRIPTION file}
\usage{
desc_get_deps(file = ".")
}
\arguments{
\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}
}
\value{
Data frame with columns: \code{type} (dependency type),
\code{package}, and \code{version}. For non-versioned dependencies
\code{version} is \code{*}.
}
\description{
List all package dependencies from a DESCRIPTION file
}
\seealso{
Other dependencies: 
\code{\link{desc_del_deps}()},
\code{\link{desc_del_dep}()},
\code{\link{desc_has_dep}()},
\code{\link{desc_set_deps}()},
\code{\link{desc_set_dep}()}
}
\concept{dependencies}
