% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_get_built}
\alias{desc_get_built}
\title{Query the built field in DESCRIPTION}
\usage{
desc_get_built(file = ".", normalize = FALSE)
}
\arguments{
\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\value{
A list with fields \code{R}, \code{Platform}, \code{Date},
\code{OStype}.
}
\description{
If the file has no \code{Built} field then it throws an error.
}
\concept{built}
