% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_validate}
\alias{desc_validate}
\title{Validate a DESCRIPTION file}
\usage{
desc_validate(file = ".")
}
\arguments{
\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}
}
\description{
This function is not implemented yet.
}
