% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_add_me}
\alias{desc_add_me}
\title{Add the current user as an author to DESCRIPTION}
\usage{
desc_add_me(
  role = "ctb",
  comment = NULL,
  orcid = NULL,
  file = ".",
  normalize = FALSE
)
}
\arguments{
\item{role}{Role to set for the user, defaults to contributor.}

\item{comment}{Comment, empty by default.}

\item{orcid}{ORCID, empty by default.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Uses the Authors@R field.
}
\details{
\code{desc_add_me} is a convenience function, it adds the
current user as an author, and it needs the
\code{whoami} package to be installed. It'll add your ORCID ID
if you provide it as argument or save it as \code{ORCID_ID} environment
variable in .Renviron.
The full name is parsed using
\code{as.person} and collapsing the given name and the family name
in order to e.g. have the first and middle names together as given
name. This approach might be limited to some full name structures.
}
\seealso{
Other Authors@R: 
\code{\link{desc_add_author_gh}()},
\code{\link{desc_add_author}()},
\code{\link{desc_add_orcid}()},
\code{\link{desc_add_role}()},
\code{\link{desc_change_maintainer}()},
\code{\link{desc_coerce_authors_at_r}()},
\code{\link{desc_del_author}()},
\code{\link{desc_del_role}()},
\code{\link{desc_get_authors}()},
\code{\link{desc_get_author}()},
\code{\link{desc_get_maintainer}()},
\code{\link{desc_set_authors}()}
}
\concept{Authors@R}
