% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_set_authors}
\alias{desc_set_authors}
\title{Set authors in Authors@R, in DESCRIPTION}
\usage{
desc_set_authors(authors, file = ".", normalize = FALSE)
}
\arguments{
\item{authors}{Authors, to set, a person object, see \code{\link[utils:person]{utils::person()}}.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Set authors in Authors@R, in DESCRIPTION
}
\seealso{
Other Authors@R: 
\code{\link{desc_add_author_gh}()},
\code{\link{desc_add_author}()},
\code{\link{desc_add_me}()},
\code{\link{desc_add_orcid}()},
\code{\link{desc_add_role}()},
\code{\link{desc_change_maintainer}()},
\code{\link{desc_coerce_authors_at_r}()},
\code{\link{desc_del_author}()},
\code{\link{desc_del_role}()},
\code{\link{desc_get_authors}()},
\code{\link{desc_get_author}()},
\code{\link{desc_get_maintainer}()}
}
\concept{Authors@R}
