% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/desc-package.R
\docType{package}
\name{desc-package}
\alias{desc-package}
\alias{_PACKAGE}
\title{desc: Manipulate DESCRIPTION Files}
\description{
Tools to read, write, create, and manipulate DESCRIPTION files. It is intended for packages that create or manipulate other packages.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://desc.r-lib.org/}
  \item \url{https://github.com/r-lib/desc}
  \item Report bugs at \url{https://github.com/r-lib/desc/issues}
}

}
\author{
\strong{Maintainer}: Gábor Csárdi \email{csardi.gabor@gmail.com}

Authors:
\itemize{
  \item Kirill Müller
  \item Jim Hester \email{james.f.hester@gmail.com}
}

Other contributors:
\itemize{
  \item Maëlle Salmon (\href{https://orcid.org/0000-0002-2815-0399}{ORCID}) [contributor]
  \item Posit Software, PBC [copyright holder, funder]
}

}
\keyword{internal}
