% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/constants.R
\docType{data}
\name{cran_valid_fields}
\alias{cran_valid_fields}
\title{A list of DESCRIPTION fields that are valid according to the CRAN checks}
\format{
An object of class \code{character} of length 125.
}
\usage{
cran_valid_fields
}
\description{
A list of DESCRIPTION fields that are valid according to the CRAN checks
}
\seealso{
Other field types: 
\code{\link{cran_ascii_fields}},
\code{\link{dep_types}}
}
\concept{field types}
\keyword{datasets}
