% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_get_version}
\alias{desc_get_version}
\title{Query the package version in DESCRIPTION}
\usage{
desc_get_version(file = ".")
}
\arguments{
\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}
}
\value{
A \link[base:numeric_version]{base::package_version} object.
}
\description{
If the file has no \code{Version} field, or it is an invalid
version string, then it throws an error.
}
\seealso{
Other version numbers: 
\code{\link{desc_bump_version}()},
\code{\link{desc_set_version}()}
}
\concept{version numbers}
