% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_has_dep}
\alias{desc_has_dep}
\title{Check for a dependency}
\usage{
desc_has_dep(package, type = c("any", desc::dep_types), file = ".")
}
\arguments{
\item{package}{The package name.}

\item{type}{A dependency type or ``any`.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}
}
\value{
A logical scalar.
}
\description{
Check for a dependency
}
\seealso{
Other dependencies: 
\code{\link{desc_del_deps}()},
\code{\link{desc_del_dep}()},
\code{\link{desc_get_deps}()},
\code{\link{desc_set_deps}()},
\code{\link{desc_set_dep}()}
}
\concept{dependencies}
