% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_set_deps}
\alias{desc_set_deps}
\title{Set all package dependencies in DESCRIPTION}
\usage{
desc_set_deps(deps, file = ".", normalize = FALSE)
}
\arguments{
\item{deps}{Package dependency data frame, in the same format
returned by \code{\link[=desc_get_deps]{desc_get_deps()}}.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Set all package dependencies in DESCRIPTION
}
\seealso{
Other dependencies: 
\code{\link{desc_del_deps}()},
\code{\link{desc_del_dep}()},
\code{\link{desc_get_deps}()},
\code{\link{desc_has_dep}()},
\code{\link{desc_set_dep}()}
}
\concept{dependencies}
