% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_set}
\alias{desc_set}
\alias{desc_set_list}
\title{Set one or more fields in a DESCRIPTION file}
\usage{
desc_set(..., check = TRUE, file = ".", normalize = FALSE)

desc_set_list(key, list_value, sep = ", ", file = ".", normalize = FALSE)
}
\arguments{
\item{...}{Values to set, see details below.}

\item{check}{Whether to check the validity of the new fields.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}

\item{key}{Key to set in \code{desc_set_list()}.}

\item{list_value}{Character vector, to collapse in
\code{desc_set_list()}.}

\item{sep}{Separator string for \code{desc_set_list()} list fields.}
}
\description{
Set one or more fields in a DESCRIPTION file
}
\details{
\code{desc_set()} supports two forms, the first is two unnamed
arguments: the key and its value to set.

The second form requires named arguments: names are used as keys
and values as values to set.

\code{desc_set_list()} collapses a character vector into string,
separating the elements by commas.
}
\seealso{
Other simple queries: 
\code{\link{desc_del}()},
\code{\link{desc_fields}()},
\code{\link{desc_get_field}()},
\code{\link{desc_get}()},
\code{\link{desc_has_fields}()}
}
\concept{simple queries}
