% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/encoding.R
\name{check_encoding}
\alias{check_encoding}
\title{Check encoding of new or existing fields}
\usage{
check_encoding(self, private, new_fields)
}
\arguments{
\item{self}{Object.}

\item{private}{Private env.}

\item{new_fields}{New fields, or \code{NULL} to check existing fields.}
}
\value{
Object, invisibly.
}
\description{
If \code{new_fields} is \code{NULL}, then the existing
fields are checked. Otherwise \code{new_fields} are checked.
}
\details{
Warnings are given for non-ascii fields, if the \code{Encoding}
field is not set.
}
\keyword{internal}
