% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/syntax_checks.R
\name{check_field}
\alias{check_field}
\title{Syntactical check of a DESCRIPTION field}
\usage{
check_field(x, warn = FALSE, ...)
}
\arguments{
\item{x}{The field.}

\item{warn}{Whether to generate a warning if the syntax check fails.}

\item{...}{Additional arguments, they might be used in the future.}
}
\value{
\code{TRUE} if the field is syntactically correct,
otherwise a character vector, containing one or multiple
error messages.
}
\description{
Syntactical check of a DESCRIPTION field
}
