% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_add_urls}
\alias{desc_add_urls}
\title{Add URLs to the URL field in DESCRIPTION}
\usage{
desc_add_urls(urls, file = ".", normalize = FALSE)
}
\arguments{
\item{urls}{Character vector of URLs to add. Duplicate URLs are
eliminated.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to normalize the write when writing back
the result. See \code{\link{desc_normalize}}.}
}
\description{
Add URLs to the URL field in DESCRIPTION
}
