% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_get_collate}
\alias{desc_get_collate}
\title{Query the Collate field in DESCRIPTION}
\usage{
desc_get_collate(which = c("main", "windows", "unix"), file = ".")
}
\arguments{
\item{which}{Which collate field to use. Collate fields can
be operating system type specific.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}
}
\value{
Character vector of file names.
}
\description{
Query the Collate field in DESCRIPTION
}
\seealso{
Other Collate field: 
\code{\link{desc_add_to_collate}()},
\code{\link{desc_del_collate}()},
\code{\link{desc_del_from_collate}()},
\code{\link{desc_set_collate}()}
}
\concept{Collate field}
