% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_set_version}
\alias{desc_set_version}
\title{Set the package version in DESCRIPTION}
\usage{
desc_set_version(version, file = ".", normalize = FALSE)
}
\arguments{
\item{version}{A string or a \link[base:numeric_version]{base::package_version} object.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Both \verb{$set_version()} and \verb{$bump_version()} use dots to
separate the version number components.
}
\seealso{
Other version numbers: 
\code{\link{desc_bump_version}()},
\code{\link{desc_get_version}()}
}
\concept{version numbers}
