% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_add_to_collate}
\alias{desc_add_to_collate}
\title{Add one or more files to the Collate field, in DESCRIPTION}
\usage{
desc_add_to_collate(
  files,
  which = c("default", "all", "main", "windows", "unix"),
  file = ".",
  normalize = FALSE
)
}
\arguments{
\item{files}{Character vector, files to add.}

\item{which}{Which collate field to use. Collate fields can
be operating system type specific.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Add one or more files to the Collate field, in DESCRIPTION
}
\seealso{
Other Collate field: 
\code{\link{desc_del_collate}()},
\code{\link{desc_del_from_collate}()},
\code{\link{desc_get_collate}()},
\code{\link{desc_set_collate}()}
}
\concept{Collate field}
