% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_get_urls}
\alias{desc_get_urls}
\title{Query the URL field in DESCRIPTION}
\usage{
desc_get_urls(file = ".")
}
\arguments{
\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}
}
\value{
A character vectors or URLs. A length zero vector is returned
if there is no URL field in the package.
}
\description{
Query the URL field in DESCRIPTION
}
