% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_clear_urls}
\alias{desc_clear_urls}
\title{Remove all URLs from the URL field of DESCRIPTION}
\usage{
desc_clear_urls(file = ".", normalize = FALSE)
}
\arguments{
\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Remove all URLs from the URL field of DESCRIPTION
}
