% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_del_dep}
\alias{desc_del_dep}
\title{Remove a package dependency from DESCRIPTION}
\usage{
desc_del_dep(
  package,
  type = c("all", desc::dep_types),
  file = ".",
  normalize = FALSE
)
}
\arguments{
\item{package}{Package dependency to remove.}

\item{type}{Dependency type to remove. Sometimes a package is depended
on via multiple dependency types, e.g. \code{LinkingTo} and
\code{Imports}. Defaults to all types.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Remove a package dependency from DESCRIPTION
}
\seealso{
Other dependencies: 
\code{\link{desc_del_deps}()},
\code{\link{desc_get_deps}()},
\code{\link{desc_has_dep}()},
\code{\link{desc_set_deps}()},
\code{\link{desc_set_dep}()}
}
\concept{dependencies}
