% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_add_remotes}
\alias{desc_add_remotes}
\title{Add locations in the Remotes field in DESCRIPTION}
\usage{
desc_add_remotes(remotes, file = ".", normalize = FALSE)
}
\arguments{
\item{remotes}{Character vector of remote locations to add.
Duplicate locations are eliminated. Note that existing locations
are not updated, so if you want to \emph{change} a remote location
of a package, you need to delete the old location first and then add
the new one.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Add locations in the Remotes field in DESCRIPTION
}
