% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_set_dep}
\alias{desc_set_dep}
\title{Add a package dependency to a DESCRIPTION file}
\usage{
desc_set_dep(
  package,
  type = desc::dep_types,
  version = "*",
  file = ".",
  normalize = FALSE
)
}
\arguments{
\item{package}{Package to depend on.}

\item{type}{Dependency type.}

\item{version}{Version to depend on, for versioned dependencies.}

\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}

\item{normalize}{Whether to "normalize" (reorder and reformat) the fields when writing back
the result. See \code{\link[=desc_normalize]{desc_normalize()}}.}
}
\description{
Add a package dependency to a DESCRIPTION file
}
\seealso{
Other dependencies: 
\code{\link{desc_del_deps}()},
\code{\link{desc_del_dep}()},
\code{\link{desc_get_deps}()},
\code{\link{desc_has_dep}()},
\code{\link{desc_set_deps}()}
}
\concept{dependencies}
