% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/non-oo-api.R
\name{desc_reformat_fields}
\alias{desc_reformat_fields}
\title{Reformat fields in a DESCRIPTION file}
\usage{
desc_reformat_fields(file = ".")
}
\arguments{
\item{file}{DESCRIPTION file to use. By default the DESCRIPTION
file of the current package (i.e. the package the working directory
is part of) is used.}
}
\description{
Reformat the fields in DESCRIPTION in a standard way.
}
\seealso{
Other repair functions: 
\code{\link{desc_normalize}()},
\code{\link{desc_reorder_fields}()}
}
\concept{repair functions}
